aboutsummaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/checkout.sh4
-rw-r--r--lib/common.sh2
-rw-r--r--lib/diff.sh8
-rw-r--r--lib/gerrit.sh6
-rw-r--r--lib/git-parser.sh2
-rw-r--r--lib/globals.sh4
-rwxr-xr-xlib/make.sh2
-rw-r--r--lib/merge.sh2
-rw-r--r--lib/package.sh12
-rwxr-xr-xlib/release.sh4
-rw-r--r--lib/stamp.sh2
11 files changed, 24 insertions, 24 deletions
diff --git a/lib/checkout.sh b/lib/checkout.sh
index 9c10584..907520a 100644
--- a/lib/checkout.sh
+++ b/lib/checkout.sh
@@ -24,7 +24,7 @@
# but we also want to work with the native source code control system.
usegit=no
-# This is used by cbuild2.sh --checkout all but not by --build
+# This is used by abe.sh --checkout all but not by --build
checkout_infrastructure()
{
trace "$*"
@@ -298,7 +298,7 @@ checkout()
# dryrun "(cd ${srcdir} && git checkout ${branch})"
elif test x"${supdate}" = xyes; then
# Some packages allow the build to modify the source directory and
- # that might screw up cbuild2's state so we restore a pristine branch.
+ # that might screw up abe's state so we restore a pristine branch.
notice "Updating sources for ${tool} in ${srcdir}"
dryrun "(cd ${repodir} && git stash --all)"
dryrun "(cd ${repodir} && git reset --hard)"
diff --git a/lib/common.sh b/lib/common.sh
index 5adc94e..e23f3ec 100644
--- a/lib/common.sh
+++ b/lib/common.sh
@@ -56,7 +56,7 @@ set_dbpasswd()
dbpasswd="$1"
}
-# if --dryrun is passed to cbuild2.sh, then commands are echoed instead of
+# if --dryrun is passed to abe.sh, then commands are echoed instead of
# of executed.
dryrun()
{
diff --git a/lib/diff.sh b/lib/diff.sh
index 9465736..8b1276c 100644
--- a/lib/diff.sh
+++ b/lib/diff.sh
@@ -32,8 +32,8 @@ difftwodirs ()
echo "Diffing: ${prev} against ${next}..."
local resultsdir="${local_builds}/test-results"
- local pversion="`echo ${prev} | grep -o "test-results/cbuild[0-9a-z]*" | grep -o "cbuild[0-9a-z]*"`"
- local nversion="`echo ${next} | grep -o "test-results/cbuild[0-9a-z]*" | grep -o "cbuild[0-9a-z]*"`"
+ local pversion="`echo ${prev} | grep -o "test-results/abe[0-9a-z]*" | grep -o "abe[0-9a-z]*"`"
+ local nversion="`echo ${next} | grep -o "test-results/abe[0-9a-z]*" | grep -o "abe[0-9a-z]*"`"
diffdir="${resultsdir}/diffof-${pversion}-${nversion}"
mkdir -p ${diffdir}
@@ -111,9 +111,9 @@ diffall ()
# This produces the test file, who's header needs to look like this:
#
# Difference in testsuite results between:
-# gcc-linaro-4.8-2014.01 build i686-precise-cbuild461-oort8-i686r1
+# gcc-linaro-4.8-2014.01 build i686-precise-abe461-oort8-i686r1
# and the one before it:
-# gcc-linaro-4.8-2013.12 build i686-precise-cbuild461-oort2-i686r1
+# gcc-linaro-4.8-2013.12 build i686-precise-abe461-oort2-i686r1
# ------
testfile()
diff --git a/lib/gerrit.sh b/lib/gerrit.sh
index 410aaaa..8061ced 100644
--- a/lib/gerrit.sh
+++ b/lib/gerrit.sh
@@ -25,7 +25,7 @@
# ssh -p 29418 robert.savoye@git.linaro.org gerrit version
# this uses the git commit SHA-1
# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --code-review 0 -m "foo" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
- # ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/cbuild2 --code-review 0 -m "foobar" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
+ # ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/abe --code-review 0 -m "foobar" a87c53e83236364fe9bc7d5ffdbf3c307c64707d
# ssh -p 29418 robert.savoye@git.linaro.org gerrit query --current-patch-set gcc status:open limit:1 --format JSON
# The number used for code reviews looks like this, it's passed as a string to
@@ -37,7 +37,7 @@
# +2 Looks good to me, approved
-# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/cbuild2 --code-review "+2" -m "foobar" 55957eaff3d80d854062544dea6fc0eedcbf9247 --submit
+# ssh -p 29418 robert.savoye@git.linaro.org gerrit review --project toolchain/abe --code-review "+2" -m "foobar" 55957eaff3d80d854062544dea6fc0eedcbf9247 --submit
# local revision="@`cd ${srcdir} && git log --oneline | head -1 | cut -d ' ' -f 1`"
@@ -215,7 +215,7 @@ Your patch is being reviewed. The build step has completed with a status of: ${s
EOF
-#http://cbuild.validation.linaro.org/logs/gcc-linaro-5.0.0/
+#http://abe.validation.linaro.org/logs/gcc-linaro-5.0.0/
add_gerrit_comment ${revision} ${msgfile} ${code}
if test $? -gt 0; then
diff --git a/lib/git-parser.sh b/lib/git-parser.sh
index 5474af6..07ee400 100644
--- a/lib/git-parser.sh
+++ b/lib/git-parser.sh
@@ -64,7 +64,7 @@
# The revision designation that follows the repository, e.g.,
# binutils.git@12345
#
-# Note: cbuild allows <repo>.git/branch@revision even though
+# Note: abe allows <repo>.git/branch@revision even though
# when a revision is present, the 'branch' is only used
# in path names, since a revision implies a branch already.
#
diff --git a/lib/globals.sh b/lib/globals.sh
index d50bdb6..4b156db 100644
--- a/lib/globals.sh
+++ b/lib/globals.sh
@@ -115,7 +115,7 @@ jenkins_job_url=""
# source a user specific config file for commonly used configure options.
# These overide any of the above values.
-if test -e ~/.cbuildrc; then
- . ~/.cbuildrc
+if test -e ~/.aberc; then
+ . ~/.aberc
fi
diff --git a/lib/make.sh b/lib/make.sh
index 4dc16dc..69ffc14 100755
--- a/lib/make.sh
+++ b/lib/make.sh
@@ -107,7 +107,7 @@ build_all()
local sysroot="`${target}-gcc -print-sysroot`"
if test ! -d ${sysroot}; then
dryrun "mkdir -p /opt/linaro"
- dryrun "ln -sfnT ${cbuild_top}/sysroots/${target} ${sysroot}"
+ dryrun "ln -sfnT ${abe_top}/sysroots/${target} ${sysroot}"
fi
fi
;;
diff --git a/lib/merge.sh b/lib/merge.sh
index 83fadc9..f57625c 100644
--- a/lib/merge.sh
+++ b/lib/merge.sh
@@ -85,7 +85,7 @@ merge_branch()
month="`date +%m`"
day="`date +%d`"
- # If no email address is in ~/.cbuildrc, create one
+ # If no email address is in ~/.aberc, create one
if test x"${email}" = x; then
email="${LOGNAME}@`hostname`"
fi
diff --git a/lib/release.sh b/lib/release.sh
index 7c23626..8355321 100755
--- a/lib/release.sh
+++ b/lib/release.sh
@@ -58,7 +58,7 @@ sign_tarball()
{
trace "$*"
-# ssh -t cbuild@toolchain64 gpg --no-use-agent -q --yes --passphrase-file /home/cbuild/.config/cbuild/password --armor --sign --detach-sig --default-key cbuild "/home/cbuild/var/snapshots/gcc-linaro-${release}.tar.xz" scp cbuild@toolchain64:/home/cbuild/var/snapshots/gcc-linaro-${release}.tar.xz.asc $REL_DIR
+# ssh -t abe@toolchain64 gpg --no-use-agent -q --yes --passphrase-file /home/abe/.config/abe/password --armor --sign --detach-sig --default-key abe "/home/abe/var/snapshots/gcc-linaro-${release}.tar.xz" scp abe@toolchain64:/home/abe/var/snapshots/gcc-linaro-${release}.tar.xz.asc $REL_DIR
return 0
}
@@ -116,7 +116,7 @@ release_binutils_src()
# From: https://wiki.linaro.org/WorkingGroups/ToolChain/GCC/ReleaseProcess
# The output file name looks like this: gcc-linaro-4.8-2013.11.tar.xz.
-# The date is set by the --release option to Cbuildv2. This function is
+# The date is set by the --release option to Abe. This function is
# only called with --tarsrc or --tarball.
release_gcc_src()
{
diff --git a/lib/stamp.sh b/lib/stamp.sh
index 054ddbb..af71648 100644
--- a/lib/stamp.sh
+++ b/lib/stamp.sh
@@ -100,7 +100,7 @@ create_stamp()
# you should not proceed with processing.
#
# 255 - There is an error condition during stamp generation. This is
-# a bug in cbuild2 or the filesystem.
+# a bug in abe or the filesystem.
#
check_stamp()
{
diff --git a/lib/package.sh b/lib/package.sh
index df111b9..398ab8f 100644
--- a/lib/package.sh
+++ b/lib/package.sh
@@ -279,10 +279,10 @@ binary_sysroot()
local tag="sysroot-linaro-${clibrary}-gcc${version}-${release}-${target}"
fi
-# dryrun "cp -fr ${cbuild_top}/sysroots/${target} ${destdir}"
+# dryrun "cp -fr ${abe_top}/sysroots/${target} ${destdir}"
local destdir="/tmp/linaro.$$/${tag}"
dryrun "mkdir -p /tmp/linaro.$$"
- dryrun "ln -sfnT ${cbuild_top}/sysroots/${target} ${destdir}"
+ dryrun "ln -sfnT ${abe_top}/sysroots/${target} ${destdir}"
# Generate the install script
sysroot_install_script ${destdir}
@@ -347,7 +347,7 @@ manifest()
local srcdir="`get_srcdir ${binutils_version}`"
local binutils_revision=="`get_git_revision ${srcdir}`"
- local cbuild_revision="`get_git_revision ${cbuild_path}`"
+ local abe_revision="`get_git_revision ${abe_path}`"
rm -f ${outfile}
cat >> ${outfile} <<EOF
@@ -375,8 +375,8 @@ gdb_version=${gdb_version}
gdb_revsion=${gdb_revision}
linux_version=${linux_version}
-# Cbuild revision used
-cbuild_revision=${cbuild_revision}
+# Abe revision used
+abe_revision=${abe_revision}
EOF
@@ -513,7 +513,7 @@ binutils_src_tarball()
return 0
}
# This installs a binary tarball produced by cbuild2, and runs make check
test_binary_toolchain()
{
# Binaries get installed here if possible
@@ -513,7 +513,7 @@ binutils_src_tarball()
return 0
}
-# This installs a binary tarball produced by cbuild2, and runs make check
+# This installs a binary tarball produced by abe, and runs make check
test_binary_toolchain()
{